Documentation
¶
Index ¶
- Variables
- type MongoProxy
- func (*MongoProxy) Descriptor() ([]byte, []int)
- func (m *MongoProxy) GetAccessLog() string
- func (m *MongoProxy) GetDelay() *v2.FaultDelay
- func (m *MongoProxy) GetEmitDynamicMetadata() bool
- func (m *MongoProxy) GetStatPrefix() string
- func (m *MongoProxy) Marshal() (dAtA []byte, err error)
- func (m *MongoProxy) MarshalTo(dAtA []byte) (int, error)
- func (*MongoProxy) ProtoMessage()
- func (m *MongoProxy) Reset()
- func (m *MongoProxy) Size() (n int)
- func (m *MongoProxy) String() string
- func (m *MongoProxy) Unmarshal(dAtA []byte) error
- func (m *MongoProxy) Validate() error
- func (m *MongoProxy) XXX_DiscardUnknown()
- func (m *MongoProxy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *MongoProxy) XXX_Merge(src proto.Message)
- func (m *MongoProxy) XXX_Size() int
- func (m *MongoProxy) XXX_Unmarshal(b []byte) error
- type MongoProxyValidationError
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidLengthMongoProxy = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowMongoProxy = fmt.Errorf("proto: integer overflow") )
Functions ¶
This section is empty.
Types ¶
type MongoProxy ¶
type MongoProxy struct {
// The human readable prefix to use when emitting :ref:`statistics
// <config_network_filters_mongo_proxy_stats>`.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The optional path to use for writing Mongo access logs. If not access log
// path is specified no access logs will be written. Note that access log is
// also gated :ref:`runtime <config_network_filters_mongo_proxy_runtime>`.
AccessLog string `protobuf:"bytes,2,opt,name=access_log,json=accessLog,proto3" json:"access_log,omitempty"`
// Inject a fixed delay before proxying a Mongo operation. Delays are
// applied to the following MongoDB operations: Query, Insert, GetMore,
// and KillCursors. Once an active delay is in progress, all incoming
// data up until the timer event fires will be a part of the delay.
Delay *v2.FaultDelay `protobuf:"bytes,3,opt,name=delay,proto3" json:"delay,omitempty"`
// Flag to specify whether :ref:`dynamic metadata
// <config_network_filters_mongo_proxy_dynamic_metadata>` should be emitted. Defaults to false.
EmitDynamicMetadata bool `protobuf:"varint,4,opt,name=emit_dynamic_metadata,json=emitDynamicMetadata,proto3" json:"emit_dynamic_metadata,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*MongoProxy) Descriptor ¶
func (*MongoProxy) Descriptor() ([]byte, []int)
func (*MongoProxy) GetAccessLog ¶
func (m *MongoProxy) GetAccessLog() string
func (*MongoProxy) GetDelay ¶
func (m *MongoProxy) GetDelay() *v2.FaultDelay
func (*MongoProxy) GetEmitDynamicMetadata ¶ added in v0.6.4
func (m *MongoProxy) GetEmitDynamicMetadata() bool
func (*MongoProxy) GetStatPrefix ¶
func (m *MongoProxy) GetStatPrefix() string
func (*MongoProxy) Marshal ¶
func (m *MongoProxy) Marshal() (dAtA []byte, err error)
func (*MongoProxy) ProtoMessage ¶
func (*MongoProxy) ProtoMessage()
func (*MongoProxy) Reset ¶
func (m *MongoProxy) Reset()
func (*MongoProxy) Size ¶
func (m *MongoProxy) Size() (n int)
func (*MongoProxy) String ¶
func (m *MongoProxy) String() string
func (*MongoProxy) Unmarshal ¶
func (m *MongoProxy) Unmarshal(dAtA []byte) error
func (*MongoProxy) Validate ¶
func (m *MongoProxy) Validate() error
Validate checks the field values on MongoProxy with the rules defined in the proto definition for this message. If any rules are violated, an error is returned.
func (*MongoProxy) XXX_DiscardUnknown ¶
func (m *MongoProxy) XXX_DiscardUnknown()
func (*MongoProxy) XXX_Marshal ¶
func (m *MongoProxy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*MongoProxy) XXX_Merge ¶
func (m *MongoProxy) XXX_Merge(src proto.Message)
func (*MongoProxy) XXX_Size ¶
func (m *MongoProxy) XXX_Size() int
func (*MongoProxy) XXX_Unmarshal ¶
func (m *MongoProxy) XXX_Unmarshal(b []byte) error
type MongoProxyValidationError ¶
type MongoProxyValidationError struct {
// contains filtered or unexported fields
}
MongoProxyValidationError is the validation error returned by MongoProxy.Validate if the designated constraints aren't met.
func (MongoProxyValidationError) Cause ¶
func (e MongoProxyValidationError) Cause() error
Cause function returns cause value.
func (MongoProxyValidationError) Error ¶
func (e MongoProxyValidationError) Error() string
Error satisfies the builtin error interface
func (MongoProxyValidationError) ErrorName ¶ added in v0.7.0
func (e MongoProxyValidationError) ErrorName() string
ErrorName returns error name.
func (MongoProxyValidationError) Field ¶
func (e MongoProxyValidationError) Field() string
Field function returns field value.
func (MongoProxyValidationError) Key ¶
func (e MongoProxyValidationError) Key() bool
Key function returns key value.
func (MongoProxyValidationError) Reason ¶
func (e MongoProxyValidationError) Reason() string
Reason function returns reason value.
Click to show internal directories.
Click to hide internal directories.